==> nextcloud-24.0.5.tgz: nextcloud/apps/comments/l10n/nb.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Kommentarer",
    "You commented" : "Du kommenterte",
    "%1$s commented" : "%1$s kommentert",
    "{author} commented" : "{author} kommenterte",
    "You commented on %1$s" : "Du kommenterte på %1$s",
    "You commented on {file}" : "Du kommenterte på {file}",
    "%1$s commented on %2$s" : "%1$s kommenterte %2$s",
    "{author} commented on {file}" : "{author} kommenterte på {file}",
    "<strong>Comments</strong> for files" : "<strong>Kommentarer</strong> for filer",
    "Files app plugin to add comments to files" : "Tillegg for å legge til kommentarer til filer",
    "Edit comment" : "Rediger kommentar",
    "Delete comment" : "Slett kommentar",
    "Cancel edit" : "Avbryt endring",
    "Post comment" : "Send kommentar",
    "No comments yet, start the conversation!" : "Ingen kommentarer enda, start diskusjonen!",
    "No more messages" : "Ingen flere meldinger",
    "Retry" : "Prøv igjen",
    "_%n unread comment_::_%n unread comments_" : ["%n ulest kommentar","%n uleste kommentarer"],
    "_1 new comment_::_{unread} new comments_" : ["[uleste] nye kommentarer","{uleste} nye kommentarer"],
    "Comment" : "Kommentar",
    "Comment deleted" : "Kommentar slettet",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Du ble nevnte på \"{file}\", i en kommentar av en bruker som siden har blitt slettet",
    "{user} mentioned you in a comment on “{file}”" : "{user} nevnte deg i en kommentar på “{file}”"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-25.0.11.tgz: nextcloud/apps/comments/l10n/nb.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Kommentarer",
    "You commented" : "Du kommenterte",
    "{author} commented" : "{author} kommenterte",
    "You commented on %1$s" : "Du kommenterte på %1$s",
    "You commented on {file}" : "Du kommenterte på {file}",
    "%1$s commented on %2$s" : "%1$s kommenterte %2$s",
    "{author} commented on {file}" : "{author} kommenterte på {file}",
    "<strong>Comments</strong> for files" : "<strong>Kommentarer</strong> for filer",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "Du ble nevnt på \"{file}\", i en kommentar av en bruker som siden har blitt slettet",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} nevnte deg i en kommentar til \"{file}\"",
    "Files app plugin to add comments to files" : "Tillegg for å legge til kommentarer til filer",
    "Edit comment" : "Rediger kommentar",
    "Delete comment" : "Slett kommentar",
    "Cancel edit" : "Avbryt endring",
    "Post comment" : "Send kommentar",
    "No comments yet, start the conversation!" : "Ingen kommentarer enda, start diskusjonen!",
    "No more messages" : "Ingen flere meldinger",
    "Retry" : "Prøv igjen",
    "Unable to load the comments list" : "Kan ikke laste inn kommentarlisten",
    "_%n unread comment_::_%n unread comments_" : ["%n ulest kommentar","%n uleste kommentarer"],
    "_1 new comment_::_{unread} new comments_" : ["[uleste] nye kommentarer","{uleste} nye kommentarer"],
    "Comment" : "Kommentar",
    "An error occurred while trying to edit the comment" : "Det oppsto en feil under forsøk på å redigere kommentaren",
    "Comment deleted" : "Kommentar slettet",
    "An error occurred while trying to delete the comment" : "Det oppsto en feil under forsøk på å slette kommentaren",
    "An error occurred while trying to create the comment" : "Det oppsto en feil under forsøket på å opprette kommentaren",
    "%1$s commented" : "%1$s kommentert"
},
"nplurals=2; plural=(n != 1);");
